<?php
// Include this SEO.php file in all pages where you need dynamic SEO.

function getSEOData() {
    // Get the current page name
    $page = basename($_SERVER['PHP_SELF'], '.php');

    // Define SEO data for each page
    $seoData = [
        'index' => [
            'title' => 'Home - Explore Culture, Festivals & Delights',
            'description' => 'Discover amazing cultural experiences, festivals, destinations, and more.',
            'keywords' => 'culture, festivals, destinations, travel, food',
            'image' => 'images/home-og.webp',
        ],
        'about' => [
            'title' => 'About Us - Discover Our Story',
            'description' => 'Learn more about our mission, vision, and the team behind our journey.',
            'keywords' => 'about, mission, vision, team',
            'image' => 'images/about-og.webp',
        ],
        'food' => [
            'title' => 'Food - Dive into Culinary Delights',
            'description' => 'Explore the best food and culinary experiences around the world.',
            'keywords' => 'food, culinary, cuisine, recipes',
            'image' => 'images/food-og.webp',
        ],
        'destinations' => [
            'title' => 'Destinations - Your Travel Inspiration',
            'description' => 'Find the best travel destinations and tips for your next adventure.',
            'keywords' => 'destinations, travel, tourism, adventure',
            'image' => 'images/destinations-og.webp',
        ],
        'festivals' => [
            'title' => 'Festivals - Celebrate Culture & Traditions',
            'description' => 'Experience the most vibrant and exciting festivals worldwide.',
            'keywords' => 'festivals, celebrations, culture, events',
            'image' => 'images/festivals-og.webp',
        ],
        'gallery' => [
            'title' => 'Gallery - Visual Journey',
            'description' => 'Explore stunning visuals and photographs from our adventures.',
            'keywords' => 'gallery, photos, images, visuals',
            'image' => 'images/gallery-og.webp',
        ],
        'contact' => [
            'title' => 'Contact Us - Get in Touch',
            'description' => 'Reach out to us for inquiries, feedback, or collaborations.',
            'keywords' => 'contact, inquiries, feedback, collaborations',
            'image' => 'images/contact-og.webp',
        ],
    ];

    // Fallback to default if page data is not defined
    return $seoData[$page] ?? [
        'title' => 'Default Title',
        'description' => 'Default meta description for the website.',
        'keywords' => 'default, keywords, SEO',
        'image' => 'images/default-og.webp',
    ];
}

// Get the SEO data for the current page
$seo = getSEOData();
?>

<!-- SEO Metadata -->
<title><?php echo htmlspecialchars($seo['title']); ?></title>
<meta name="description" content="<?php echo htmlspecialchars($seo['description']); ?>">
<meta name="keywords" content="<?php echo htmlspecialchars($seo['keywords']); ?>">
<meta property="og:title" content="<?php echo htmlspecialchars($seo['title']); ?>">
<meta property="og:description" content="<?php echo htmlspecialchars($seo['description']); ?>">
<meta property="og:image" content="<?php echo htmlspecialchars($seo['image']); ?>">
<meta property="og:url" content="<?php echo htmlspecialchars((isset($_SERVER['HTTPS']) ? 'https' : 'http') . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]"); ?>">
<meta name="twitter:card" content="summary_large_image">
<meta name="twitter:title" content="<?php echo htmlspecialchars($seo['title']); ?>">
<meta name="twitter:description" content="<?php echo htmlspecialchars($seo['description']); ?>">
<meta name="twitter:image" content="<?php echo htmlspecialchars($seo['image']); ?>">

<!-- JSON-LD Schema -->
<script type="application/ld+json">
{
    "@context": "https://schema.org",
    "@type": "WebPage",
    "name": "<?php echo htmlspecialchars($seo['title']); ?>",
    "description": "<?php echo htmlspecialchars($seo['description']); ?>",
    "image": "<?php echo htmlspecialchars($seo['image']); ?>",
    "url": "<?php echo htmlspecialchars((isset($_SERVER['HTTPS']) ? 'https' : 'http') . '://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']); ?>"
}
</script>
